// checking program for problem "Grouping"
//
// ./grouping-check  problem.input  contestant.output
//
// returns  0       if correct
//          nonzero if incorrect


#include <iostream>
#include <fstream>
#include <map>
#include <vector>
#include <string>
#include <cstdio>


using namespace std;


vector<string> codeName; // codeName[num] = name
map<string,int> codeNameMap; // codeNameMap[name] = num
typedef map<string,int>::const_iterator MapIt;

int numCodePieces; // kind of redundant, just for convenience
vector<bool> visited;
vector<vector<int> > adj; // adj list
typedef vector<int>::const_iterator VI;
vector<int> order;  //  numbering of vertices


int getCodeNameNum(const string& name) {
    MapIt it = codeNameMap.find(name);
    if (it == codeNameMap.end()) {
	// new name, create necessary stuff
	codeNameMap[name] = numCodePieces;
	codeName.push_back(name);
	numCodePieces++;
	adj.resize(numCodePieces);
	return numCodePieces-1; // return the index of name, so -1
    } else {
	return it->second;
    }
}



int main(int argc, char *argv[])
{
    if (argc != 3) {
	fprintf(stderr, "Usage:  %s  problem.input  contestant.output\n",
		argv[0]);
	return 1;
    }


    ifstream input(argv[1]);
    if (!input) {
	fprintf(stderr, "Cannot open problem input file %s\n", argv[1]);
	return 1;
    }
    numCodePieces = 0;
    for (;;) {
	string thisCodeName;
	input >> thisCodeName;
	if (thisCodeName == "END") break;
	int thisNum = getCodeNameNum(thisCodeName);
	int numNeeds;
	input >> numNeeds;
	for (int i = 0; i < numNeeds; i++) {
	    string neededName;
	    input >> neededName;
	    int num = getCodeNameNum(neededName);
	    adj[thisNum].push_back(num);  // reverse of original
	}
    }
    input.close();

    vector<int> answer;
    answer.resize(numCodePieces, 0);

    FILE *output = fopen(argv[2], "r");
    if (output == NULL) {
	fprintf(stderr, "Cannot open contestant output file %s\n", argv[2]);
	return 1;
    }

    for (int i = 0; i <= numCodePieces; i++) {
	char name[105];
	if (fgets(name, 100, output) == NULL) {
	    if (i >= numCodePieces) break;  // done, the extra one passed
	    if (i < numCodePieces) {
		// fprintf(stderr, "More ouput expected for %s\n", argv[2]);
		printf("Wrong answer (too few output)\n");
		return 2;
	    }
	    // fprintf(stderr, "Too much output for %s\n", argv[2]);
	    printf("Wrong answer (too much output)\n");
	}
	name[strlen(name)-1] = '\0'; // remove linefeed
	string thisCodeName = name;
	if (codeNameMap.find(name) == codeNameMap.end()) {
	    printf("Wrong answer (code name '%s' not exist)\n", name);
	    return 2;
	}
	answer[codeNameMap[thisCodeName]] = i;
    }
    fclose(output);

    // now compare the dependency
    for (int vertex = 0; vertex < numCodePieces; vertex++) {
	int thisNum = answer[vertex];
	for (VI it = adj[vertex].begin(); it != adj[vertex].end(); it++) {
	    int depNum = answer[*it];
	    if (thisNum <= depNum) {
		printf("Wrong answer (wrong dependency)\n");
		return 2;
	    }
	}
    }

    printf("Correct\n");
    return 0;
}

