// C++ solution by Thomas
//
// Algorithm: Topological Sort

#include <iostream>
#include <map>
#include <vector>
#include <string>
#include <cstdio>


using namespace std;


vector<string> codeName; // codeName[num] = name
map<string,int> codeNameMap; // codeNameMap[name] = num
typedef map<string,int>::const_iterator MapIt;

int numCodePieces; // kind of redundant, just for convenience
vector<bool> visited;
vector<vector<int> > adj; // adj list
typedef vector<int>::const_iterator VI;
vector<int> order;  //  numbering of vertices


int getCodeNameNum(const string& name) {
    MapIt it = codeNameMap.find(name);
    if (it == codeNameMap.end()) {
	// new name, create necessary stuff
	codeNameMap[name] = numCodePieces;
	codeName.push_back(name);
	numCodePieces++;
	adj.resize(numCodePieces);
	return numCodePieces-1; // return the index of name, so -1
    } else {
	return it->second;
    }
}


void walkForSort(int vertex) {
    visited[vertex] = true;
    for (VI it = adj[vertex].begin(); it != adj[vertex].end(); it++) {
	if (!visited[*it]) {
	    walkForSort(*it);
	}
    }
    order.insert(order.begin(), vertex);  // insert at front
}


void topoSort() {
    int i;
    visited.clear();
    visited.resize(numCodePieces, false);
    order.clear();
    for (i = 0; i < numCodePieces; i++) {
	if (!visited[i]) {
	    walkForSort(i);
	}
    }
}



int main()
{
    numCodePieces = 0;
    for (;;) {
	string thisCodeName;
	cin >> thisCodeName;
	if (thisCodeName == "END") break;
	int thisNum = getCodeNameNum(thisCodeName);
	int numNeeds;
	cin >> numNeeds;
	for (int i = 0; i < numNeeds; i++) {
	    string neededName;
	    cin >> neededName;
	    int num = getCodeNameNum(neededName);
	    adj[num].push_back(thisNum);
	}
    }
    
    topoSort();
    for (int i = 0; i < numCodePieces; i++) {
	cout << codeName[order[i]] << endl;
    }
    return 0;
}

